BaseHttpService class base

Constructors

BaseHttpService({Protocol? protocol, required String service, GetClient? mockedGetClient, PostClient? mockedPostClient})
Returns the new instance of BaseHttpService.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(String unencodedPath, {Map<String, dynamic>? parameters, ResponseDataBuilder<T>? to, ResponseDataAdaptor? adaptor}) Future<Response<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post<T>(String unencodedPath, {Map<String, String>? headers, dynamic body, ResponseDataBuilder<T>? to}) Future<Response<T>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited